# Projeto SARCI
 > Projeto que visa a Automação do Relatório de Controle Interno sobre as contas de Gestão de todos os órgãos da Prefeitura Municipal de Fortaleza,
 a fim de melhorar o trabalho do servidor público por meio da eliminação de processos manuais envolvidos na elaborção do mesmo,
 podendo assim realizar uma análise mais cirúrgica de seus resultados.

# Autores
[@Gui507](https://github.com/Gui507/)
[@soyEldvd](https://github.com/soyEldvd)
[@Levy3006](https://github.com/Levy3006)
[@MatheusWillamy](https://github.com/MatheusWillamy)
[@amandapaulav](https://github.com/amandapaulav)
[@brendatavares](https://github.com/brendatavares)
